intelmq.bots.outputs.udp package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.outputs.udp package

## Submodules

## intelmq.bots.outputs.udp.output module

`intelmq.bots.outputs.udp.output.` `BOT`

  alias of `intelmq.bots.outputs.udp.output.UDPOutputBot`

class `intelmq.bots.outputs.udp.output.` `UDPOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `delimited`(event)
  `init`()
  `is_multithreadable` = False
  `process`()
  `remove_control_char`(s)
  `send`(rawdata)

## Module contents